@@ -1,9 +1,9 @@
-/* Copyright(C) 2005 Stefan Siegl <ssiegl@gmx.de>
+/* Copyright(C) 2005,2007 Stefan Siegl <stesie@brokenpipe.de>
  * taxbird - free program to interface with German IRO's Elster/Coala
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -19,7 +19,7 @@
 #ifndef TAXBIRD_EXPORT_H
 #define TAXBIRD_EXPORT_H
 
-void taxbird_export(GtkWidget *appwin, int testcase);
+void taxbird_export(int testcase);
 
 int taxbird_export_bottom_half(GtkWidget *confirm_dlg);
 
