@@ -1,4 +1,4 @@
-/* Copyright(C) 2004,2005,2007,2008 Stefan Siegl <stesie@brokenpipe.de>
+/* Copyright(C) 2004,2005,2007,2008,2010 Stefan Siegl <stesie@brokenpipe.de>
  * taxbird - free program to interface with German IRO's Elster/Coala
  *
  * This program is free software; you can redistribute it and/or modify
@@ -504,8 +504,13 @@ taxbird_ws_show_appbar_help(GtkWidget *widget, GdkEventFocus *event,
 void
 taxbird_ws_open(const char *fname, gboolean copy_last_year)
 {
-  SCM handle = scm_open_file(scm_makfrom0str(fname),
+  /* Matthias Jansen/2009-03-10: read from STDIN if filename is "-" */
+  SCM handle;
+  if (strncmp(fname,"-",1))
+	  handle = scm_open_file(scm_makfrom0str(fname),
 			     scm_makfrom0str("r"));
+  else
+  	handle = scm_current_input_port();
 
   SCM content = scm_eval_x(scm_read(handle), scm_current_module());
 
@@ -524,6 +529,7 @@ taxbird_ws_open(const char *fname, gboolean copy_last_year)
     }
   }
 
+
   char *formname = scm_to_locale_string(SCM_CAR(content));
   taxbird_ws_sel_form(taxbird_form_get_by_name(formname));
   free(formname);
@@ -532,9 +538,15 @@ taxbird_ws_open(const char *fname, gboolean copy_last_year)
   if(SCM_NFALSEP(scm_list_p(taxbird_document_data)))
     scm_gc_unprotect_object(taxbird_document_data);
   taxbird_document_data = scm_gc_protect_object(SCM_CADR(content));
+  
+  /* recalculate the whole sheet */
+  scm_call_1(taxbird_current_form->dataset_recalc, taxbird_document_data);
 
-  taxbird_document_filename = g_strdup(fname);
-  taxbird_document_changed = 0;
+  /* Matthias Jansen/2009-03-11: only save the filename if it is not "-" */
+  if (strcmp(fname, "-")) {
+    taxbird_document_filename = g_strdup(fname);
+    taxbird_document_changed = 0;
+  }
 }
 
 
